@@ -1,9 +1,12 @@
 match.data <- function(object, group = "all", distance = "distance",
                        weights = "weights", subclass = "subclass") {
-  data <- eval(object$call$data)
-  if (!is.data.frame(data) & !is.null(object$model))
-    data <- eval(object$call$data,
-                 env = attr(terms(object$model), ".Environment"))
+
+  if (!is.null(object$model)) {
+    env <- attributes(terms(object$model))$.Environment
+  } else {
+    env <- parent.frame()
+  }
+  data <- eval(object$call$data, envir = env)
   treat <- object$treat
   wt <- object$weights
   vars <- names(data)
